| expression | R Documentation |
Evaluate a formula on the data.frame.
expression_(df, group=NULL, fun_expr)
df |
data.frame |
group |
formula that describes the group |
fun_expr |
formula that describes the expression to be run on the data.frame |
The function returns a list.
Each element of the list get the result of processed expressions determined in ... on the whole data frame df if group is kept NULL, or for each group determined in group otherwise.
The class of each element is intrinsic to the output of the expression determined in argument ....
expression_(CO2,fun_expr=~mean(conc)) expression_(CO2,fun_expr=~conc/uptake) # with group expression_(CO2,group=~Type,fun_expr=~mean(uptake)) expression_(CO2,group=~Type,fun_expr=~lm(uptake~conc))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.