| summarise | R Documentation |
Summarise of formulas on a data.frame.
summarise_(df, group = NULL, ...)
df |
data.frame |
group |
formula that describes the group |
... |
formulas to be generated |
summarise_() returns a data frame.
If argument group is not NULL, output get its first columns called according to the names present in argument group.
The following columns are called according to the name of each argument present in ....
Each row corresponds to processed expressions determined in ... for each group determined in group, or over the whole data frame if group is NULL.
summarise_(CO2,a=~mean(uptake),b=~sd(uptake)) summarise_(CO2, group=~c(Type,Treatment),a=~mean(uptake),b=~sd(uptake))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.